@@ -1,4 +1,5 @@
-from collections import Mapping, Hashable
+from pyrsistent._compat import Mapping, Hashable
+import six
 from operator import add
 import pytest
 from pyrsistent import pmap, m, PVector
